@@ -9,7 +9,11 @@ from ..Signal import Signal
 
 class MatRecordLoader(RecordLoader):
     def __init__(self, filePath, targetSignals, targetSignalTypes) -> None:
-        super().__init__(filePath=filePath, targetSignals=targetSignals, targetSignalTypes=targetSignalTypes)
+        super().__init__(
+            filePath=filePath,
+            targetSignals=targetSignals,
+            targetSignalTypes=targetSignalTypes,
+        )
         self.WFDBRecordLoader = None
         self.samplingRate = 200
         self.extension = ".mat"
